@@ -6,12 +6,16 @@ The “out-of-line”, “API mode” gives you the most flexibility and speed t
 import cffi
 from pathlib import Path
 
-with open(str(Path(__file__).absolute().parent / 'build_cffi.c-files.txt'), 'r') as f:
+__folder__ = Path(__file__).absolute().parent
+with open(__folder__.joinpath('build_cffi.c-files.txt').as_posix(), 'r') as f:
     sources = f.read().strip().splitlines()
 # end with
 
+ext_dir = __folder__.joinpath('_image_intensities')
+sources = [ext_dir.joinpath(s).as_posix() for s in sources]
+
 ffibuilder = cffi.FFI()
-ffibuilder.set_source(
+args = dict(
     module_name="image_intensities._native_code._image_intensities",
     source="""
     #include "_native_code/definitions.h"
@@ -33,7 +37,13 @@ ffibuilder.set_source(
         "-DPPM_SUPPORTED",
         "-DBMP_SUPPORTED",
     ],
+
 )
+
+print('ffibuilder args')
+print(args)
+
+ffibuilder.set_source(**args)
 ffibuilder.cdef("""
     struct intensity_data {
         double nw;
